@@ -156,12 +156,12 @@ def _qtwebengine_features(  # noqa: C901
 
     if versions.webengine >= utils.VersionNumber(6, 7):
         # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-132681
-        # TODO adjust if fixed in Qt 6.8.2/.3 or 6.9.0/.1
+        # TODO adjust if fixed in Qt 6.9.2+
         disabled_features.append('DocumentPictureInPictureAPI')
 
-    if versions.webengine == utils.VersionNumber(6, 9):
+    if utils.VersionNumber(6, 9) <= versions.webengine < utils.VersionNumber(6, 10, 1):
         # WORKAROUND for https://bugreports.qt.io/browse/QTBUG-135787
-        # TODO adjust if still present in 6.9.1
+        # and https://bugreports.qt.io/browse/QTBUG-141096
         disabled_features.append('PermissionElement')
 
     if not config.val.input.media_keys:
@@ -356,7 +356,21 @@ _WEBENGINE_SETTINGS: dict[str, dict[Any, Optional[_SettingValueType]]] = {
     'qt.workarounds.disable_accelerated_2d_canvas': {
         'always': '--disable-accelerated-2d-canvas',
         'never': None,
-        'auto': lambda _versions: '--disable-accelerated-2d-canvas' if machinery.IS_QT6 else None,
+        'auto': lambda versions: '--disable-accelerated-2d-canvas'
+        if machinery.IS_QT6
+        and versions.webengine
+        and versions.webengine < utils.VersionNumber(6, 8, 2)
+        else None,
+    },
+    'qt.workarounds.disable_accessibility': {
+        'always': '--disable-renderer-accessibility',
+        'never': None,
+        # WORKAROUND for https://qt-project.atlassian.net/browse/QTBUG-142320
+        'auto': lambda versions: '--disable-renderer-accessibility'
+        if machinery.IS_QT6
+        and versions.webengine
+        and versions.webengine == utils.VersionNumber(6, 10, 1)
+        else None,
     },
 }
 
