@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: Florian Bruhin (The Compiler) <mail@qutebrowser.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
 # pyright: reportConstantRedefinition=false
 
 """Qt wrapper selection.
@@ -26,15 +30,15 @@ import argparse
 import warnings
 import importlib
 import dataclasses
-from typing import Optional, Dict
+from typing import Optional
 
 from qutebrowser.utils import log
 
 # Packagers: Patch the line below to enforce a Qt wrapper, e.g.:
-# sed -i 's/_WRAPPER_OVERRIDE = .*/_WRAPPER_OVERRIDE = "PyQt6"/' qutebrowser/qt/machinery.py
+# sed -i 's/_WRAPPER_OVERRIDE = "PyQt6"
 #
 # Users: Set the QUTE_QT_WRAPPER environment variable to change the default wrapper.
-_WRAPPER_OVERRIDE = "PyQt5"  # type: ignore[var-annotated]
+_WRAPPER_OVERRIDE = "PyQt6"
 
 WRAPPERS = [
     "PyQt6",
@@ -102,7 +106,7 @@ class SelectionInfo:
     """Information about outcomes of importing Qt wrappers."""
 
     wrapper: Optional[str] = None
-    outcomes: Dict[str, str] = dataclasses.field(default_factory=dict)
+    outcomes: dict[str, str] = dataclasses.field(default_factory=dict)
     reason: SelectionReason = SelectionReason.unknown
 
     def set_module_error(self, name: str, error: Exception) -> None:
